ProSHADE: Class Members

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

Here is a list of all documented class members with links to the class documentation for each member:

### - o -

- originalMapXCom : ProSHADE_internal_data::ProSHADE_data
- originalMapYCom : ProSHADE_internal_data::ProSHADE_data
- originalMapZCom : ProSHADE_internal_data::ProSHADE_data
- originalPdbRotCenX : ProSHADE_internal_data::ProSHADE_data
- originalPdbRotCenY : ProSHADE_internal_data::ProSHADE_data
- originalPdbRotCenZ : ProSHADE_internal_data::ProSHADE_data
- originalPdbTransX : ProSHADE_internal_data::ProSHADE_data
- originalPdbTransY : ProSHADE_internal_data::ProSHADE_data
- originalPdbTransZ : ProSHADE_internal_data::ProSHADE_data
- outName : ProSHADE_settings
- overlayStructureName : ProSHADE_settings